<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xhtml="http://www.w3.org/1999/xhtml"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:exsl="http://exslt.org/common"
> 

	<xsl:output method="xml" encoding="UTF-8" />
	<!-- 
		Analyse a generic web page resembling an image gallery,
    and return a vanilla list of the thumbnails and image links found in it.
    
    Discards almost all layout and other detail.

		.dan.
	-->

	<!--
		If $xmlid is set, this document will insert xml:id along with normal html:id
	-->
	<xsl:param name="xmlid"></xsl:param>

	<xsl:template name="html_doc" match="/*[not(descendant::exsl:document)]">	
	<!-- 
	Main page layout.
	Current context node is either exsl:document or the html tag.
	Either way, head and body are the immediate children.
	-->
		<html>
		<head>
		<!-- META And Header extraction -->
		
	    <title>
			<xsl:call-template name="get-title" />
	    </title>

		<xsl:text>
		</xsl:text>

		<meta name="description" id="teaser" >
			<xsl:if test="$xmlid"><xsl:attribute name="xml:id">teaser</xsl:attribute></xsl:if>
			<xsl:attribute name="value">
				<xsl:call-template name="get-description" />
			</xsl:attribute>
		</meta>

		<xsl:for-each select=".//head|.//xhtml:head">
			<xsl:for-each select="meta[@name]|xhtml:meta[@name]|rel|xhtml:rel|style|xhtml:style">
				<!-- copy most of the head - but NOT metas with http-equiv -->
				<xsl:copy><xsl:for-each select="@*"><xsl:copy></xsl:copy></xsl:for-each></xsl:copy>
			</xsl:for-each>
		<xsl:text>
		</xsl:text>
		</xsl:for-each>
		
		</head>
		<xsl:text>
		
		</xsl:text>
		<body>
			<h1 id="pagetitle">
				<xsl:if test="$xmlid"><xsl:attribute name="xml:id">pagetitle</xsl:attribute></xsl:if>
				<xsl:call-template name="get-title" />
			</h1>
			<div id="content">
				<xsl:if test="$xmlid"><xsl:attribute name="xml:id">content</xsl:attribute></xsl:if>
				<xsl:call-template name="get-content" />
			</div>
		</body>

		</html>
	</xsl:template>




	<xsl:template name="get-title">
			<xsl:choose>
	
				<xsl:when test="descendant::*[local-name()='h1']">
			    	<xsl:value-of select="normalize-space(descendant::*[local-name()='h1'])" />
				</xsl:when>
				
				<xsl:when test="//*[@id='pagetitle']">
					<!-- 
						Nice sites set the id of their title.
						May add other #ids here as I find them
					-->
			    	<xsl:value-of select="normalize-space(descendant::*[@id='pagetitle'])" />
				</xsl:when>

				<xsl:when test="count(descendant::h2|descendant::xhtml:h2)=1">
					<!-- 
						Maybe it used an h2 because h1 was ugly.
						If there is ONLY ONE h2, use that
					-->
			    	<xsl:value-of select="normalize-space(descendant::h2|descendant::xhtml:h2)" />
				</xsl:when>
				
				<xsl:otherwise>
					<!-- 
						In practice, the html head title is often more verbose than we want
						and too often it's the same across whole sections, but it'll have to do.
					-->
			    	<xsl:value-of select="normalize-space(descendant::*[name() = 'title'])" />
				</xsl:otherwise>
				<!--
				  Any of these steps may fail if the heading contains only html, eg
				  <h1><img src='header.gif' /></h1>
				-->
			</xsl:choose>
	</xsl:template>
	
	<xsl:template name="get-content">
		<!--	
       Scan for all href links.
       If it appears to link to a jpg
       List them, including the text or thumbnails inside them.
       Stop.
		-->
    <xsl:for-each select="//node()[@href]" >

      <xsl:choose>

        <xsl:when test="contains(@href, '.jpg')">
          <xsl:copy>
            <xsl:attribute name="class" >link link-to-image</xsl:attribute>
            <xsl:attribute name="rel" >nodereference</xsl:attribute>
            <xsl:apply-templates select="@*|node()"/>
          </xsl:copy>
          <xsl:text>
          </xsl:text>
        </xsl:when>

        <xsl:when test="contains(@href, '.mpg')">
          <xsl:copy>
            <xsl:attribute name="class" >link link-to-video</xsl:attribute>
            <xsl:attribute name="rel" >nodereference</xsl:attribute>
            <xsl:apply-templates select="@*|node()"/>
          </xsl:copy>
          <xsl:text>
          </xsl:text>
        </xsl:when>

      </xsl:choose>
 
    </xsl:for-each>
	</xsl:template>



	
	<xsl:template name="get-description">
		<!-- 
			Look for 
			a defined meta tag, 
			a 'description' id, 
			a 'description' class, 
			or the first paragraph. 
			In that order.
			Description text is a flat string with no formatting!
		-->
		<xsl:choose>
			<xsl:when test="descendant::xhtml:meta[@name='description']">
		    	<xsl:value-of select="descendant::meta[@name='description']" />
			</xsl:when>
			<xsl:when test="descendant::*[@id='description']">
		    	<xsl:value-of select="descendant::*[@id='description']" />
			</xsl:when>
			<xsl:when test="descendant::*[@class='description']">
		    	<xsl:value-of select="descendant::*[@class='description']" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="set" select="descendant::p|descendant::xhtml:p"/>
				<xsl:for-each select="$set[1]">
					<xsl:value-of select="descendant::*[@class='description']" />
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- Identity transformation template - to inline existing HTML  -->			
	<xsl:template name="passthrough" match="@*|node()|text()">
	  <xsl:copy>
		<xsl:apply-templates select="@*|node()|text()"/>
	  </xsl:copy>
	</xsl:template>

</xsl:stylesheet>